@@ -22,8 +22,8 @@ use strict;
 use warnings;           # Must be used in test mode only. This reduce a little process speed
 #use diagnostics;       # Must be used in test mode only. This reduce a lot of process speed
 
-use lib qw(/opt/asnmtap/.);
-use ASNMTAP::Asnmtap::Plugins v3.000.003;
+use lib qw(/opt/asnmtap-3.000.xxx/. /opt/asnmtap/.);
+use ASNMTAP::Asnmtap::Plugins v3.000.004;
 use ASNMTAP::Asnmtap::Plugins qw(:DEFAULT :ASNMTAP :PLUGINS :MODEM);
 
 use Getopt::Long;
